Struct google_doubleclickbidmanager1::ListQueriesResponse [−][src]
List queries response.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- listqueries queries (response)
Fields
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "doubleclickbidmanager#listQueriesResponse".
queries: Option<Vec<Query>>
Retrieved queries.